pub struct QueuedDatagram {
pub delivery_time: Instant,
pub payload: Vec<u8>,
pub src: SocketAddr,
pub dst: SocketAddr,
}Expand description
Represents a datagram that has been queued for simulated delivery.
Fields
delivery_time: InstantThe instant at which this datagram should be delivered.
payload: Vec<u8>The raw payload of the datagram.
src: SocketAddrThe source address of the datagram.
dst: SocketAddrThe destination address of the datagram.