Module network

Module network 

Network simulation engine with configurable latency, loss, jitter, reordering, and bandwidth.

Structs

NetworkConfig
Configuration for the simulated network conditions.
SimulatedNetwork
A simulated network that models latency, jitter, loss, duplication, and reordering.