pub struct NetworkConfig {
pub latency: Duration,
pub jitter: Duration,
pub loss_rate: f64,
pub burst_loss_prob: f64,
pub reorder_rate: f64,
pub duplicate_prob: f64,
pub bandwidth: Option<u64>,
pub nat_rebind_prob: f64,
}Expand description
Configuration for the simulated network conditions.
Fields
latency: DurationBase latency for packets.
jitter: DurationMaximum additional random delay added to packets.
loss_rate: f64Probability of a packet being dropped (0.0 to 1.0).
burst_loss_prob: f64Probability of entering or continuing a burst loss state (0.0 to 1.0).
reorder_rate: f64Probability of a packet being delayed extra to cause reordering (0.0 to 1.0).
duplicate_prob: f64Probability of a packet being duplicated (0.0 to 1.0).
bandwidth: Option<u64>Maximum bandwidth in bytes per second (for transmission rate delay calculation).
nat_rebind_prob: f64Probability of a NAT rebinding occurring, changing the source port.